# ccfit2

ccfit2 is a package for fitting AC and DC magnetisation data to obtain magnetic
relaxation rates, and then to model the field- and/or temperature-dependence of
these rates with parameterised models of spin-phonon coupling mechanisms.

## Installation

See the [`ccfit2`](https://chilton-group.gitlab.io/cc-fit2/installation). documentation for installation instructions.

## Documentation

The online documentation for `ccfit2` can be found [here](https://chilton-group.gitlab.io/cc-fit2/).
